@@ -25,12 +25,13 @@ class data_manager(object):
             self.t_data['charset'] = 'utf8mb4'
 
         self.threading_pool = {}
+        self.threading_out_time_pool = {}
         self.sql_pool = {}
         print('creating DB connection pool...')
         # for i in range(0,self.min_keep_connection):
         self.new()
         print('connect done!')
-        IntervalTask(data_manager.keep_cycle, self.keep_connect)
+        # IntervalTask(data_manager.keep_cycle, self.keep_connect)
         self.mem_cache = {}
 
 
@@ -41,6 +42,7 @@ class data_manager(object):
             return self.t_data['database']+'.'+table_name
 
     def keep_connect(self):
+        pass
         # print('查看死亡链接')
         # can_delete_sql = []
         # count = 0
@@ -57,18 +59,18 @@ class data_manager(object):
         #         sql.become_free()
         # return
         # <===================>
-        can_delete_sql_id_list = []
-        count = 0
-        for sql in self.sql_pool.values():
-            if int(time.time()) - sql.last_execute_time > 40:
-                count += 1
-                can_delete_sql_id_list.append(id(sql))
-        self.kill_unused_connection(can_delete_sql_id_list)
-        for sql in self.sql_pool.values():
-            if sql.is_busy() == False:
-                sql.become_busy()
-                sql.keep_connect()
-                sql.become_free()
+        # can_delete_sql_id_list = []
+        # count = 0
+        # for sql in self.sql_pool.values():
+        #     if int(time.time()) - sql.last_execute_time > 40:
+        #         count += 1
+        #         can_delete_sql_id_list.append(id(sql))
+        # self.kill_unused_connection(can_delete_sql_id_list)
+        # for sql in self.sql_pool.values():
+        #     if sql.is_busy() == False:
+        #         sql.become_busy()
+        #         sql.keep_connect()
+        #         sql.become_free()
 
 
     def kill_unused_connection(self, kill_connect):
@@ -114,16 +116,20 @@ class data_manager(object):
         # print('本次数据库请求线程id', thread_id)
 
         if thread_id in self.threading_pool:
-            sql_id = self.threading_pool[thread_id]
-            if sql_id in self.sql_pool:
-                sql = self.sql_pool[sql_id]
-                sql.become_busy()
-                return sql
+            if self.threading_out_time_pool[thread_id] - int(time.time()) > 30:
+                sql_id = self.threading_pool[thread_id]
+                if sql_id in self.sql_pool:
+                    sql = self.sql_pool[sql_id]
+                    sql.become_busy()
+                    self.threading_out_time_pool[thread_id] = int(time.time())
+                    return sql
 
         sql = self.create_new_sql()
         sql.become_busy()
         self.add_new_sql(sql)
         self.threading_pool[thread_id] = id(sql)
+        self.threading_out_time_pool[thread_id] = int(time.time())
+        print('为线程%s更新数据库链接%s'%(thread_id,id(sql)))
         return sql
 
     def add_new_sql(self, sql):
